/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_addoninterface_wrapper.h"

// Extra includes
#include <QList>

using namespace Phonon;

// Native ---------------------------------------------------------

AddonInterfaceWrapper::AddonInterfaceWrapper() : Phonon::AddonInterface() {
    // ... middle
}

bool AddonInterfaceWrapper::hasInterface(Phonon::AddonInterface::Interface iface) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasInterface"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'AddonInterface.hasInterface()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Phonon::AddonInterface::Interface >::toPython(iface)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "AddonInterface.hasInterface", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QVariant AddonInterfaceWrapper::interfaceCall(Phonon::AddonInterface::Interface iface, int command, const QList<QVariant > & arguments)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "interfaceCall"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'AddonInterface.interfaceCall()' not implemented.");
        return QVariant(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiN)",
        Shiboken::Converter< ::Phonon::AddonInterface::Interface >::toPython(iface),
        command,
        Shiboken::Converter< ::QList<QVariant > >::toPython(arguments)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "AddonInterface.interfaceCall", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

AddonInterfaceWrapper::~AddonInterfaceWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Phonon_AddonInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::AddonInterface >()))
        return -1;

    AddonInterfaceWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'Phonon::AddonInterface' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // AddonInterface()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new AddonInterfaceWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::AddonInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_Phonon_AddonInterfaceFunc_hasInterface(PyObject* self, PyObject* arg)
{
    Phonon::AddonInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::AddonInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasInterface(Phonon::AddonInterface::Interface)const
    if (Shiboken::Converter< ::Phonon::AddonInterface::Interface >::isConvertible(arg)) {
        overloadId = 0; // hasInterface(Phonon::AddonInterface::Interface)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_AddonInterfaceFunc_hasInterface_TypeError;

    // Call function/method
    {
        {
            Phonon::AddonInterface::Interface cppArg0 = Shiboken::Converter<Phonon::AddonInterface::Interface >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasInterface(Phonon::AddonInterface::Interface)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'AddonInterface.hasInterface()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->hasInterface(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_AddonInterfaceFunc_hasInterface_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::AddonInterface.Interface", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AddonInterface.hasInterface", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_AddonInterfaceFunc_interfaceCall(PyObject* self, PyObject* args, PyObject* kwds)
{
    Phonon::AddonInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::AddonInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.AddonInterface.interfaceCall(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.AddonInterface.interfaceCall(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:interfaceCall", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: interfaceCall(Phonon::AddonInterface::Interface,int,QList<QVariant>)
    if (numArgs >= 2 && Shiboken::Converter< ::Phonon::AddonInterface::Interface >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // interfaceCall(Phonon::AddonInterface::Interface,int,QList<QVariant>)
        } else if (Shiboken::Converter< ::QList<QVariant > >::isConvertible(pyargs[2])) {
            overloadId = 0; // interfaceCall(Phonon::AddonInterface::Interface,int,QList<QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_AddonInterfaceFunc_interfaceCall_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "arguments");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "arguments";
                    else if (Shiboken::Converter< ::QList<QVariant > >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_Phonon_AddonInterfaceFunc_interfaceCall_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.phonon.AddonInterface.interfaceCall(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Phonon::AddonInterface::Interface cppArg0 = Shiboken::Converter<Phonon::AddonInterface::Interface >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QList<QVariant > cppArg2 = pyargs[2] ? Shiboken::Converter<QList<QVariant > >::toCpp(pyargs[2]) : QList< QVariant >();

            if(!PyErr_Occurred()) {
                // interfaceCall(Phonon::AddonInterface::Interface,int,QList<QVariant>)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'AddonInterface.interfaceCall()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = cppSelf->interfaceCall(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_AddonInterfaceFunc_interfaceCall_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::AddonInterface.Interface, int, list = QList< QVariant >()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.AddonInterface.interfaceCall", overloads);
        return 0;
}

static PyMethodDef Sbk_Phonon_AddonInterface_methods[] = {
    {"hasInterface", (PyCFunction)Sbk_Phonon_AddonInterfaceFunc_hasInterface, METH_O},
    {"interfaceCall", (PyCFunction)Sbk_Phonon_AddonInterfaceFunc_interfaceCall, METH_VARARGS|METH_KEYWORDS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_AddonInterface_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.AddonInterface",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_AddonInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_Phonon_AddonInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_Phonon_AddonInterface(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_AddonInterface_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_Phonon_AddonInterface_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_Phonon_AddonInterface_Type, &Shiboken::callCppDestructor<Phonon::AddonInterface >);
    if (PyType_Ready((PyTypeObject*)&Sbk_Phonon_AddonInterface_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_Phonon_AddonInterface_Type, "Phonon::AddonInterface*");
    PyDict_SetItemString(module,"AddonInterface", (PyObject*)&Sbk_Phonon_AddonInterface_Type);
    // Initialize enums
    PyObject* enumItem;

    // init enum: SubtitleCommand
    PyTypeObject* SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand = Shiboken::Enum::newType("SubtitleCommand");
    SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_SUBTITLECOMMAND_IDX] = SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand;
    if (PyType_Ready(SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,
            "SubtitleCommand",((PyObject*)SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand,(long) Phonon::AddonInterface::availableSubtitles, "availableSubtitles");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"availableSubtitles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand->tp_dict,"availableSubtitles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand,(long) Phonon::AddonInterface::currentSubtitle, "currentSubtitle");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"currentSubtitle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand->tp_dict,"currentSubtitle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand,(long) Phonon::AddonInterface::setCurrentSubtitle, "setCurrentSubtitle");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"setCurrentSubtitle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_SubtitleCommand->tp_dict,"setCurrentSubtitle", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface::SubtitleCommand");
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface$ConcreteWrapper::SubtitleCommand");
    // end of enum SubtitleCommand

    // init enum: TitleCommand
    PyTypeObject* SbkPySide_phonon_Phonon_AddonInterface_TitleCommand = Shiboken::Enum::newType("TitleCommand");
    SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_TITLECOMMAND_IDX] = SbkPySide_phonon_Phonon_AddonInterface_TitleCommand;
    if (PyType_Ready(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,
            "TitleCommand",((PyObject*)SbkPySide_phonon_Phonon_AddonInterface_TitleCommand));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand,(long) Phonon::AddonInterface::availableTitles, "availableTitles");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"availableTitles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand->tp_dict,"availableTitles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand,(long) Phonon::AddonInterface::title, "title");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"title", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand->tp_dict,"title", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand,(long) Phonon::AddonInterface::setTitle, "setTitle");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"setTitle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand->tp_dict,"setTitle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand,(long) Phonon::AddonInterface::autoplayTitles, "autoplayTitles");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"autoplayTitles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand->tp_dict,"autoplayTitles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand,(long) Phonon::AddonInterface::setAutoplayTitles, "setAutoplayTitles");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"setAutoplayTitles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_TitleCommand->tp_dict,"setAutoplayTitles", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface::TitleCommand");
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface$ConcreteWrapper::TitleCommand");
    // end of enum TitleCommand

    // init enum: Interface
    PyTypeObject* SbkPySide_phonon_Phonon_AddonInterface_Interface = Shiboken::Enum::newType("Interface");
    SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_INTERFACE_IDX] = SbkPySide_phonon_Phonon_AddonInterface_Interface;
    if (PyType_Ready(SbkPySide_phonon_Phonon_AddonInterface_Interface) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,
            "Interface",((PyObject*)SbkPySide_phonon_Phonon_AddonInterface_Interface));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_Interface,(long) Phonon::AddonInterface::NavigationInterface, "NavigationInterface");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"NavigationInterface", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_Interface->tp_dict,"NavigationInterface", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_Interface,(long) Phonon::AddonInterface::ChapterInterface, "ChapterInterface");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"ChapterInterface", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_Interface->tp_dict,"ChapterInterface", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_Interface,(long) Phonon::AddonInterface::AngleInterface, "AngleInterface");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"AngleInterface", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_Interface->tp_dict,"AngleInterface", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_Interface,(long) Phonon::AddonInterface::TitleInterface, "TitleInterface");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"TitleInterface", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_Interface->tp_dict,"TitleInterface", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_Interface,(long) Phonon::AddonInterface::SubtitleInterface, "SubtitleInterface");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"SubtitleInterface", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_Interface->tp_dict,"SubtitleInterface", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_Interface,(long) Phonon::AddonInterface::AudioChannelInterface, "AudioChannelInterface");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"AudioChannelInterface", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_Interface->tp_dict,"AudioChannelInterface", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface::Interface");
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface$ConcreteWrapper::Interface");
    // end of enum Interface

    // init enum: AudioChannelCommand
    PyTypeObject* SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand = Shiboken::Enum::newType("AudioChannelCommand");
    SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_AUDIOCHANNELCOMMAND_IDX] = SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand;
    if (PyType_Ready(SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,
            "AudioChannelCommand",((PyObject*)SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand,(long) Phonon::AddonInterface::availableAudioChannels, "availableAudioChannels");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"availableAudioChannels", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand->tp_dict,"availableAudioChannels", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand,(long) Phonon::AddonInterface::currentAudioChannel, "currentAudioChannel");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"currentAudioChannel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand->tp_dict,"currentAudioChannel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand,(long) Phonon::AddonInterface::setCurrentAudioChannel, "setCurrentAudioChannel");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"setCurrentAudioChannel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_AudioChannelCommand->tp_dict,"setCurrentAudioChannel", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface::AudioChannelCommand");
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface$ConcreteWrapper::AudioChannelCommand");
    // end of enum AudioChannelCommand

    // init enum: ChapterCommand
    PyTypeObject* SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand = Shiboken::Enum::newType("ChapterCommand");
    SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_CHAPTERCOMMAND_IDX] = SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand;
    if (PyType_Ready(SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,
            "ChapterCommand",((PyObject*)SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand,(long) Phonon::AddonInterface::availableChapters, "availableChapters");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"availableChapters", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand->tp_dict,"availableChapters", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand,(long) Phonon::AddonInterface::chapter, "chapter");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"chapter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand->tp_dict,"chapter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand,(long) Phonon::AddonInterface::setChapter, "setChapter");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"setChapter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_ChapterCommand->tp_dict,"setChapter", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface::ChapterCommand");
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface$ConcreteWrapper::ChapterCommand");
    // end of enum ChapterCommand

    // init enum: NavigationCommand
    PyTypeObject* SbkPySide_phonon_Phonon_AddonInterface_NavigationCommand = Shiboken::Enum::newType("NavigationCommand");
    SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_NAVIGATIONCOMMAND_IDX] = SbkPySide_phonon_Phonon_AddonInterface_NavigationCommand;
    if (PyType_Ready(SbkPySide_phonon_Phonon_AddonInterface_NavigationCommand) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,
            "NavigationCommand",((PyObject*)SbkPySide_phonon_Phonon_AddonInterface_NavigationCommand));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_NavigationCommand,(long) Phonon::AddonInterface::Menu1Button, "Menu1Button");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"Menu1Button", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_NavigationCommand->tp_dict,"Menu1Button", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface::NavigationCommand");
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface$ConcreteWrapper::NavigationCommand");
    // end of enum NavigationCommand

    // init enum: AngleCommand
    PyTypeObject* SbkPySide_phonon_Phonon_AddonInterface_AngleCommand = Shiboken::Enum::newType("AngleCommand");
    SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_ANGLECOMMAND_IDX] = SbkPySide_phonon_Phonon_AddonInterface_AngleCommand;
    if (PyType_Ready(SbkPySide_phonon_Phonon_AddonInterface_AngleCommand) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,
            "AngleCommand",((PyObject*)SbkPySide_phonon_Phonon_AddonInterface_AngleCommand));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_AngleCommand,(long) Phonon::AddonInterface::availableAngles, "availableAngles");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"availableAngles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_AngleCommand->tp_dict,"availableAngles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_AngleCommand,(long) Phonon::AddonInterface::angle, "angle");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"angle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_AngleCommand->tp_dict,"angle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_AddonInterface_AngleCommand,(long) Phonon::AddonInterface::setAngle, "setAngle");
    PyDict_SetItemString(Sbk_Phonon_AddonInterface_Type.super.ht_type.tp_dict,"setAngle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_AddonInterface_AngleCommand->tp_dict,"setAngle", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface::AngleCommand");
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::AddonInterface$ConcreteWrapper::AngleCommand");
    // end of enum AngleCommand


    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AddonInterface >("Phonon::AddonInterface*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AddonInterface >("Phonon::AddonInterface$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AddonInterface >(typeid(Phonon::AddonInterface).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AddonInterface >(typeid(AddonInterfaceWrapper).name());
    PySide::initQtMetaType<Phonon::AddonInterface* >();
}

